@@ -1,10 +1,12 @@
 from .diversity_metrics import DiversityMetrics
+from .ranking_distance import RankingDistance
 from .ranking_metrics import RankingMetrics
 from .relevance_metrics import CosineRelevanceMetric, InnerProductRelevanceMetric
 
 __all__ = [
     "DiversityMetrics",
+    "RankingDistance",
+    "RankingMetrics",
     "CosineRelevanceMetric",
     "InnerProductRelevanceMetric",
-    "RankingMetrics",
 ]
